@@ -84,6 +84,8 @@ class ChromeAPI(object):
             tab_id = match.groupdict().get("tab_id")
             # title = match.groupdict().get("title")
             tabs.append(self.getInfo(tab_id=tab_id))
+        if len(tabs) == 1:
+            return tabs[0]
         return tabs
 
     def findTabs(self, name="xTeVe"):
